===============================
Stockfighter
===============================

.. image:: https://img.shields.io/pypi/v/stockfighter.svg
        :target: https://pypi.python.org/pypi/stockfighter

.. image:: https://img.shields.io/travis/striglia/stockfighter.svg
        :target: https://travis-ci.org/striglia/stockfighter

.. image:: https://readthedocs.org/projects/stockfighter/badge/?version=latest
        :target: https://readthedocs.org/projects/stockfighter/?badge=latest
        :alt: Documentation Status


API wrapper for Stockfighter

* Free software: ISC license
* Documentation someday at: https://stockfighter.readthedocs.org.

Get things started
--------

Not hard!

.. code-block:: shell

    pip install stockfighter

.. code-block:: python

    from stockfighter import Stockfighter
    s = Stockfighter(venue='TESTEX', account='EXB123456')
    print s.venue_stocks()

Features
--------

* Calling the API is pretty important :)
* .....get back to me later on what else
